@@ -52,11 +52,11 @@ FLOAT_TYPES = set([
 ])
 
 REQUIRED_CONFIG_KEYS = [
-    'sid',
-    'host',
-    'port',
-    'user',
-    'password'
+   'sid',
+   'host',
+   'port',
+   'user',
+   'password'
 ]
 
 def nullable_column(col_name, col_type, pks_for_table):
@@ -351,7 +351,12 @@ def do_sync_incremental(conn_config, stream, state, desired_columns):
    replication_key = md_map.get((), {}).get('replication-key')
    if not replication_key:
       raise Exception("No replication key selected for key-based incremental replication")
-   LOGGER.info("Stream %s is using incremental replication with replication key %s", stream.tap_stream_id, replication_key)
+
+   if conn_config.get('incremental_limit'):
+     LOGGER.info("Stream %s is using incremental replication with replication key %s and optional limit %s",
+                 stream.tap_stream_id, replication_key, conn_config['incremental_limit'])
+   else:
+      LOGGER.info("Stream %s is using incremental replication with replication key %s", stream.tap_stream_id, replication_key)
 
    # make sure state has required keys for incremental stream
    stream_state = state.get('bookmarks', {}).get(stream.tap_stream_id)
@@ -460,6 +465,7 @@ def sync_traditional_stream(conn_config, stream, state, sync_method, end_scn):
          state = full_table.sync_view(conn_config, stream, state, desired_columns)
       else:
          state = full_table.sync_table(conn_config, stream, state, desired_columns)
+
    elif sync_method == 'log_initial':
       #start off with full-table replication
       state = singer.set_currently_syncing(state, stream.tap_stream_id)
@@ -469,11 +475,13 @@ def sync_traditional_stream(conn_config, stream, state, sync_method, end_scn):
 
       common.send_schema_message(stream, [])
       state = full_table.sync_table(conn_config, stream, state, desired_columns)
+
    elif sync_method == 'log_initial_interrupted':
       LOGGER.info("Initial stage of full table sync was interrupted. resuming...")
       state = singer.set_currently_syncing(state, stream.tap_stream_id)
       common.send_schema_message(stream, [])
       state = full_table.sync_table(conn_config, stream, state, desired_columns)
+
    elif sync_method == 'incremental':
       state = singer.set_currently_syncing(state, stream.tap_stream_id)
       state = do_sync_incremental(conn_config, stream, state, desired_columns)
@@ -534,8 +542,12 @@ def main_impl():
                   'port': args.config['port'],
                   'sid':  args.config['sid']}
 
+   if args.config.get('incremental_limit'):
+      conn_config['incremental_limit'] = args.config.get('incremental_limit')
+
    if args.config.get('scn_window_size'):
       log_miner.SCN_WINDOW_SIZE=int(args.config['scn_window_size'])
+
    if args.discover:
       filter_schemas_prop = args.config.get('filter_schemas')
       filter_schemas = []
